pub enum ThemeMode {
System,
Light,
Dark,
}Expand description
Options that control theme mode behavior.
Variants
System
Follows the operating system appearance when resolving the active theme.
Light
Forces the light Liora theme regardless of system appearance.
Dark
Forces the dark Liora theme regardless of system appearance.
Implementations
Sourceimpl ThemeMode
impl ThemeMode
Sourcepub fn value(self) -> &'static str
pub fn value(self) -> &'static str
Returns the serialized value used by forms, configuration, or persistence.
Sourcepub fn from_value(value: &str) -> Option<ThemeMode>
pub fn from_value(value: &str) -> Option<ThemeMode>
Parses a serialized value into the corresponding strongly typed option.
Sourcepub fn resolve(self, appearance: WindowAppearance) -> Theme
pub fn resolve(self, appearance: WindowAppearance) -> Theme
Resolves this mode into a concrete light or dark theme.
Sourcepub fn from_theme(theme: &Theme) -> ThemeMode
pub fn from_theme(theme: &Theme) -> ThemeMode
Creates this value from theme.