pub struct SelectableTextCopy;Trait Implementations
Sourceimpl Action for SelectableTextCopy
impl Action for SelectableTextCopy
Sourcefn name_for_type() -> &'static strwhere
Self: Sized,
fn name_for_type() -> &'static strwhere
Self: Sized,
Get the name of this action type (static)
Sourcefn partial_eq(&self, action: &dyn Action) -> bool
fn partial_eq(&self, action: &dyn Action) -> bool
Do a partial equality check on this action and the other
Sourcefn boxed_clone(&self) -> Box<dyn Action>
fn boxed_clone(&self) -> Box<dyn Action>
Clone the action into a new box
Sourcefn build(_value: Value) -> Result<Box<dyn Action>>
fn build(_value: Value) -> Result<Box<dyn Action>>
Build this action from a JSON value. This is used to construct actions from the keymap.
A value of
{} will be passed for actions that don’t have any parameters.Sourcefn action_json_schema(_generator: &mut SchemaGenerator) -> Option<Schema>
fn action_json_schema(_generator: &mut SchemaGenerator) -> Option<Schema>
Optional JSON schema for the action’s input data.
Sourcefn deprecated_aliases() -> &'static [&'static str]
fn deprecated_aliases() -> &'static [&'static str]
A list of alternate, deprecated names for this action. These names can still be used to
invoke the action. In Zed, the keymap JSON schema will accept these old names and provide
warnings.
Sourcefn deprecation_message() -> Option<&'static str>
fn deprecation_message() -> Option<&'static str>
Returns the deprecation message for this action, if any. In Zed, the keymap JSON schema will
cause this to be displayed as a warning.
Sourcefn documentation() -> Option<&'static str>
fn documentation() -> Option<&'static str>
The documentation for this action, if any. When using the derive macro for actions
this will be automatically generated from the doc comments on the action struct.
Sourceimpl Clone for SelectableTextCopy
impl Clone for SelectableTextCopy
Sourcefn clone(&self) -> SelectableTextCopy
fn clone(&self) -> SelectableTextCopy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SelectableTextCopy
impl Debug for SelectableTextCopy
Sourceimpl Default for SelectableTextCopy
impl Default for SelectableTextCopy
Sourcefn default() -> SelectableTextCopy
fn default() -> SelectableTextCopy
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for SelectableTextCopy
impl PartialEq for SelectableTextCopy
Sourcefn eq(&self, other: &SelectableTextCopy) -> bool
fn eq(&self, other: &SelectableTextCopy) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SelectableTextCopy