Timer

Struct Timer 

pub struct Timer { /* private fields */ }
Fluent native GPUI component for rendering Liora timer.

Implementations

Source

impl Timer

pub fn count_up(elapsed: Duration) -> Self

Sets the count up value used by the component.

pub fn count_down(duration: Duration, elapsed: Duration) -> Self

Sets the count down value used by the component.

pub fn new( direction: TimerDirection, elapsed: Duration, duration: Option<Duration>, ) -> Self

Creates Timer initialized from the supplied direction, elapsed, and duration.

pub fn id(self, id: impl Into<SharedString>) -> Self

Assigns a stable element id used by GPUI state, hit testing, and automated interaction tests.

pub fn elapsed(self, elapsed: Duration) -> Self

Sets the elapsed value used by the component.

pub fn duration(self, duration: Duration) -> Self

Sets the duration value used by the component.

pub fn direction(self, direction: TimerDirection) -> Self

Selects the layout or animation direction.

pub fn countup(self) -> Self

Sets the countup value used by the component.

pub fn countdown(self) -> Self

Sets the countdown value used by the component.

pub fn display_unit(self, unit: TimerUnit) -> Self

Sets the display unit value used by the component.

pub fn format(self, format: TimerFormat) -> Self

Sets the format displayed or consumed by the component.

pub fn clock_format(self) -> Self

Sets the clock format value used by the component.

pub fn show_unit(self, show: bool) -> Self

Configures whether unit is visible in the rendered component.

pub fn title(self, title: impl Into<SharedString>) -> Self

Sets the primary title text displayed by the component.

pub fn prefix(self, prefix: impl Into<SharedString>) -> Self

Sets the prefix value used by the component.

pub fn suffix(self, suffix: impl Into<SharedString>) -> Self

Sets the suffix value used by the component.

pub fn compact(self) -> Self

Sets the compact value used by the component.

pub fn running(self, running: bool) -> Self

Sets the running value used by the component.

pub fn start(self) -> Self

Sets the start value used by the component.

pub fn paused(self) -> Self

Sets the paused value used by the component.

pub fn tick_interval(self, interval: Duration) -> Self

Sets the tick interval value used by the component.

pub fn snapshot(&self) -> TimerSnapshot

Performs the snapshot operation used by this component.

pub fn elapsed_as(&self, unit: TimerUnit) -> f64

Performs the elapsed as operation used by this component.

pub fn remaining_as(&self, unit: TimerUnit) -> Option<f64>

Performs the remaining as operation used by this component.