pub struct TimerSnapshot {
pub elapsed: Duration,
pub remaining: Option<Duration>,
pub finished: bool,
}Expand description
Fluent native GPUI component for rendering Liora timer snapshot.
Fields
elapsed: DurationElapsed duration tracked by a timer.
remaining: Option<Duration>Remaining duration before a timer completes.
finished: boolWhether a countdown timer has reached completion.
Implementations
Sourceimpl TimerSnapshot
impl TimerSnapshot
Sourcepub fn elapsed_as(self, unit: TimerUnit) -> f64
pub fn elapsed_as(self, unit: TimerUnit) -> f64
Performs the elapsed as operation used by this component.
Sourcepub fn remaining_as(self, unit: TimerUnit) -> Option<f64>
pub fn remaining_as(self, unit: TimerUnit) -> Option<f64>
Performs the remaining as operation used by this component.