pub struct VirtualTreeItem {
pub id: SharedString,
pub label: SharedString,
pub depth: u32,
pub has_children: bool,
}Expand description
Visible tree row produced from the expanded tree model.
Fields
id: SharedStringlabel: SharedStringdepth: u32has_children: boolTrait Implementations
Sourceimpl Clone for VirtualTreeItem
impl Clone for VirtualTreeItem
Sourcefn clone(&self) -> VirtualTreeItem
fn clone(&self) -> VirtualTreeItem
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VirtualTreeItem
impl Debug for VirtualTreeItem
impl Eq for VirtualTreeItem
Sourceimpl PartialEq for VirtualTreeItem
impl PartialEq for VirtualTreeItem
Sourcefn eq(&self, other: &VirtualTreeItem) -> bool
fn eq(&self, other: &VirtualTreeItem) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for VirtualTreeItem