pub struct Timer { /* private fields */ }Expand description
Fluent native GPUI component for rendering Liora timer.
Implementations
Sourceimpl Timer
impl Timer
Sourcepub fn count_down(duration: Duration, elapsed: Duration) -> Self
pub fn count_down(duration: Duration, elapsed: Duration) -> Self
Sets the count down value used by the component.
Sourcepub fn new(
direction: TimerDirection,
elapsed: Duration,
duration: Option<Duration>,
) -> Self
pub fn new( direction: TimerDirection, elapsed: Duration, duration: Option<Duration>, ) -> Self
Creates Timer initialized from the supplied direction, elapsed, and duration.
Sourcepub fn id(self, id: impl Into<SharedString>) -> Self
pub fn id(self, id: impl Into<SharedString>) -> Self
Assigns a stable element id used by GPUI state, hit testing, and automated interaction tests.
Sourcepub fn duration(self, duration: Duration) -> Self
pub fn duration(self, duration: Duration) -> Self
Sets the duration value used by the component.
Sourcepub fn direction(self, direction: TimerDirection) -> Self
pub fn direction(self, direction: TimerDirection) -> Self
Selects the layout or animation direction.
Sourcepub fn display_unit(self, unit: TimerUnit) -> Self
pub fn display_unit(self, unit: TimerUnit) -> Self
Sets the display unit value used by the component.
Sourcepub fn format(self, format: TimerFormat) -> Self
pub fn format(self, format: TimerFormat) -> Self
Sets the format displayed or consumed by the component.
Sourcepub fn clock_format(self) -> Self
pub fn clock_format(self) -> Self
Sets the clock format value used by the component.
Sourcepub fn show_unit(self, show: bool) -> Self
pub fn show_unit(self, show: bool) -> Self
Configures whether unit is visible in the rendered component.
Sourcepub fn title(self, title: impl Into<SharedString>) -> Self
pub fn title(self, title: impl Into<SharedString>) -> Self
Sets the primary title text displayed by the component.
Sourcepub fn prefix(self, prefix: impl Into<SharedString>) -> Self
pub fn prefix(self, prefix: impl Into<SharedString>) -> Self
Sets the prefix value used by the component.
Sourcepub fn suffix(self, suffix: impl Into<SharedString>) -> Self
pub fn suffix(self, suffix: impl Into<SharedString>) -> Self
Sets the suffix value used by the component.
Sourcepub fn tick_interval(self, interval: Duration) -> Self
pub fn tick_interval(self, interval: Duration) -> Self
Sets the tick interval value used by the component.
Sourcepub fn snapshot(&self) -> TimerSnapshot
pub fn snapshot(&self) -> TimerSnapshot
Performs the snapshot operation used by this component.
Sourcepub fn elapsed_as(&self, unit: TimerUnit) -> f64
pub fn elapsed_as(&self, unit: TimerUnit) -> f64
Performs the elapsed as operation used by this component.
Sourcepub fn remaining_as(&self, unit: TimerUnit) -> Option<f64>
pub fn remaining_as(&self, unit: TimerUnit) -> Option<f64>
Performs the remaining as operation used by this component.